function options = optionset(varargin)

%OPTIONS = OPTIONSET('NAME1',VALUE1,'NAME2',VALUE2,...) creates an 
%   options structure OPTIONS in which the named properties have the
%   specified values. Any unspecified properties have default values.
%
%          RelTime: [ positive scalar  {0} ]\n');
%           AbsPre: [ positive scalar {1e-6} ]\n');
%          Display: [ on | {off} ]\n');
%          PlotVar: [ vector  ]\n'); 
%            Style: [plotting styles--dash,dots,boldlines,bolddash,bolddots]\n');
%            Color: [plotting colors--g,r,b,c,m,y,k,w]\n');
%          nbunits: [number of processors used for simulation]\n');
%

Names = [
    'RelTime       '
    'AbsPre        '
    'Display       '
    'PlotVar       '
    'Style         '
    'Color         '
    'nbunits       '
    ];
m = size(Names,1);
names = lower(Names);

% Combine all leading options structures o1, o2, ... in optionset(o1,o2,...)
options = [];

for j = 1:m
  options.(deblank(Names(j,:))) = [];
end
i = 1;
while i <= nargin
  arg = varargin{i};
  if ischar(arg)                         % arg is an option name
    break;
  end
  if ~isempty(arg)                      % [] is a valid options argument
    if ~isa(arg,'struct')
      error('MATLAB:optionset:NoPropNameOrStruct',...
            ['Expected argument %d to be a string property name ' ...
                     'or an options structure\ncreated with OPTIONSET.'], i);
    end
    for j = 1:m
      if any(strcmp(fieldnames(arg),deblank(Names(j,:))))
        val = arg.(deblank(Names(j,:)));
      else
        val = [];
      end
      if ~isempty(val)
        options.(deblank(Names(j,:))) = val;
      end
    end
  end
  i = i + 1;
end

% A finite state machine to parse name-value pairs.
if rem(nargin-i+1,2) ~= 0
  error('MATLAB:optionset:ArgNameValueMismatch',...
        'Arguments must occur in name-value pairs.');
end
expectval = 0;                          % start expecting a name, not a value
while i <= nargin
  arg = varargin{i};
    
  if ~expectval
    if ~ischar(arg)
      error('MATLAB:optionset:NoPropName',...
            'Expected argument %d to be a string property name.', i);
    end
    
    lowArg = lower(arg);
    j = strmatch(lowArg,names);
    if isempty(j)                       % if no matches
      error('MATLAB:optionset:InvalidPropName',...
            'Unrecognized property name ''%s''.', arg);
    elseif length(j) > 1                % if more than one match
      % Check for any exact matches (in case any names are subsets of others)
      k = strmatch(lowArg,names,'exact');
      if length(k) == 1
        j = k;
      else
        msg = sprintf('Ambiguous property name ''%s'' ', arg);
        msg = [msg '(' deblank(Names(j(1),:))];
        for k = j(2:length(j))'
          msg = [msg ', ' deblank(Names(k,:))];
        end
        msg = sprintf('%s).', msg);
        error('MATLAB:optionset:AmbiguousPropName', msg);
      end
    end
    expectval = 1;                      % we expect a value next
    
  else
    options.(deblank(Names(j,:))) = arg;
    expectval = 0;
      
  end
  i = i + 1;
end

if expectval
  error('MATLAB:optionset:NoValueForProp',...
        'Expected value for property ''%s''.', arg);
end

% code based on the implementation done in
% Matlab\toolbox\matlab\funfun\odeset.m