function saveModel(oModel)

% SAVEMODEL     save the models, the integrators files in a folder and
%                   creat an instalmodel.m file to use later.
%
%   input :     model object
%
%   
%
% Version 1, october 2008
% Marc Hafner, EPFL-IC-LANOS, Switzerland
% help and comments to marc.hafner@epfl.ch
%



% checking, creating folder for saving
i=1;
ok=0;
while i<3 && ok==0
    disp(['Saving model   ' oModel.tModelName])
    reply = input(['Default folder:   ./' oModel.tModelName '   Do you agree y/n [y]? '],'s');

    if isempty(reply)==0 && (reply=='N' || reply=='n')
        folder = input('Specify folder (subfolder of the current folder) : ','s');
    else
        folder = oModel.tModelName;
    end
    folder = [ './' folder '/'];
    disp(['Chosen folder is :  ' folder])

    [s,mess] = mkdir(folder);
    
    if s~=1
        disp('Error : folder not created');
    elseif isempty(mess)==0
        disp(['Warning: ' mess]);
        reply = input('Do you want to overwrite the folder and files y/n [n]? ', 's');
        if isempty(reply)==0 && (reply=='y' || reply=='Y')
            ok=1;
        end
    else
        ok=1;
    end
    i=1+i;
end

if ok~=1
    error('Wrong choice of folder / folder creation');
end

% saving model/files
save([folder 'model.mat'], 'oModel');
[s,mess]=mkdir([folder '/integrators/']);

copyfile([oModel.tPath '/*'], [folder '/integrators/'],'f');


% creating install file
install = fopen([folder '/installmodel.m'],'w');

fprintf(install,'%% install function for model %s\n', oModel.tModelName);
fprintf(install,'%% \n');
fprintf(install,'%% launch file to install model and integrators files on the computer\n');
fprintf(install,'%% \n');
fprintf(install,'%% version sept 08\n');

fprintf(install,' \n');
fprintf(install,'load model.mat; \n');
fprintf(install,' \n');

fprintf(install,'SelectWorkingPath\n\n');
fprintf(install,'if bioSimworkingpath(end)==''\\'' || bioSimworkingpath(end)==''/''\n\tbioSimworkingpath=bioSimworkingpath(1:end-1);\nend\n');
fprintf(install,'tPath = [bioSimworkingpath ''/models/%s'']; \n', oModel.tModelName);
fprintf(install,'if (exist(tPath,''dir'')~=0) \n');
fprintf(install,'\treply=input(''Folder for integrator already exist, overwrite y/n [n]?'',''s'');\n\n');

fprintf(install,'\tif isempty(reply)==0 && (reply==''y'' || reply==''Y'')\n');
fprintf(install,'\t\tstatus=copyfile (''./integrators/*'', [tPath ''/''],''f'');\n\telse\n');
fprintf(install,'\t\tstatus=1;\n\tend\n');
fprintf(install,'else\n\tmkdir(tPath);\n');
fprintf(install,'\tstatus=copyfile (''./integrators/*'', [tPath ''/''],''f'');\nend\n');
fprintf(install,' \n');

fprintf(install,'if status==0;\n\tdisp(''Error while copying files'');\nend\n');
fprintf(install,'addpath(tPath);\noModel.tPath = tPath;\n');

fprintf(install,' \n');
fprintf(install,'global DisplayMode \n');
fprintf(install,'if isempty(DisplayMode)==1\n');
fprintf(install,'\tdisplayDisplayModes();\n');
fprintf(install,'\tDisplayMode = input(''Please set DisplayMode, 0-5: '');\nend\n');

fprintf(install,'\n%s= oModel;\nclear oModel\n\n',oModel.tModelName);

fprintf(install,'clear status tPath replay\n');
fprintf(install,'disp(''Installation of %s completed'')\n',oModel.tModelName);

fclose(install);

disp(['Saving of model   ' oModel.tModelName '   completed']);



